@@ -9,7 +9,7 @@ import f61d.LOGO as LOGO
 from math import ceil
 from tqdm import *
 
-VERSION = (0,2,10)
+VERSION = (0,3,1)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -28,8 +28,13 @@ help_cont[6] = 'Nim      : An interesting turtle game.'
 help_cont[7] = 'getLogo  : Print the "F61D" LOGO.'
 help_cont[8] = 'yinyang  : Draw the TaiJi.'
 help_cont[2] = 'timeit   : Take a time for your function.\n\t\t  Just add a '+colored('@timeit','cyan')+colored(' before you define the function','green')
+help_cont[10] = 'Polynomial: from f61d.Polynomial2 import *'
+help_cont[11] = 'gmgj     : Common Modulus Attack in RSA'
 
-
+def formatNumber(x):
+    if len(str(x)) == 1:
+        return ' '+str(x)
+    return str(x)
 
 def Help(page=1,lines = 5):
     if type(page) != int or type(lines) != int:
@@ -46,7 +51,7 @@ def Help(page=1,lines = 5):
         try:
             n = i+lines*(page-1)
             ll = colored(help_cont[n],'green')
-            print(f'   {n} - '+ll)
+            print(f'   {formatNumber(n)} - '+ll)
         except:break
     print('\n'+colored(f"{'=-'*14}= ",'yellow')+f"page({page}/{maxPage})"+colored(f" {'=-'*14}=",'yellow'))
     if page < maxPage:print(colored(f'\t\t\thelp({page+1}) for next page','green'))
@@ -183,4 +188,28 @@ def yinyang():
     import f61d.yinyang
     f61d.yinyang.main()
     
+def gmgj(n, c1, c2, e1, e2):#共模攻击
+    '''
+        共模攻击
+        gmpy2 is required
+    '''
+    from gmpy2 import invert
+    def egcd(a, b):
+        if b == 0:
+            return a, 0
+        else:
+            x, y = egcd(b, a % b)
+            return y, x - (a // b) * y
     
+    s = egcd(e1, e2)
+    s1 = s[0]
+    s2 = s[1]
+    if s1 < 0:
+        s1 = - s1
+        c1 = invert(c1, n)
+    elif s2 < 0:
+        s2 = - s2
+        c2 = invert(c2, n)
+    m = pow(c1, s1, n) * pow(c2, s2, n) % n
+    print(bytes.fromhex(hex(m)[2:]))
+    return m
